//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/View/Instrument/InstrumentsQListView.h
//! @brief     Defines class InstrumentsQListView.
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_VIEW_INSTRUMENT_INSTRUMENTSQLISTVIEW_H
#define BORNAGAIN_GUI_VIEW_INSTRUMENT_INSTRUMENTSQLISTVIEW_H

#include <QListView>

class InstrumentItem;
class InstrumentsQListModel;

//! Instrument selector on the left side of InstrumentView.

class InstrumentsQListView : public QListView {
    Q_OBJECT
public:
    InstrumentsQListView();
    ~InstrumentsQListView();

    QSize sizeHint() const override;
    QSize minimumSizeHint() const override;

    InstrumentItem* currentInstrumentItem() const;

signals:
    void instrumentSelected(InstrumentItem* instrument);

private slots:
    void onItemSelectionChanged();
    void onNewGisas();
    void onNewOffspec();
    void onNewSpecular();
    void onNewDepthprobe();

    void onRemove();
    void onCopy();

    void onStoreInLibrary() const;
    void onLoadFromLibrary();

private:
    void updateActions();
    void ensureItemSelected();
    void restoreSelection();

    InstrumentsQListModel* m_model;

    static QString m_xml_dir;
};

#endif // BORNAGAIN_GUI_VIEW_INSTRUMENT_INSTRUMENTSQLISTVIEW_H
